import requests
from typing import Any, Dict


def authenticate_db(email: str, api_key: str) -> Dict[str, Any]:
    params = {'email': email, 'api_key': api_key}
    res = requests.get(
        'http://api.auth.adolet.com/authenticate',
        params=params,
    )
    res = res.json()

    database_url = {
        'dbname': res['dbname'],
        'user': res['user'],
        'password': res['password'],
        'host': res['host'],
        'port': res['port'],
    }
    return database_url



import pickle
from typing import TypeVar

POSTGRESREPO = TypeVar('PostgresRepo')
CACHE_FILE = 'cache_postgres_repo.cache'


def cache_postgres_repo(postgres_repo: POSTGRESREPO) -> bool:
    '''Save the Postgres Repo class instance in a .pkl which will in essence act like a cache'''
    # Save cache in .pkl file
    with open(CACHE_FILE, 'wb') as handle:
        pickle.dump(
            postgres_repo,
            handle,
            protocol=pickle.HIGHEST_PROTOCOL,
        )
    print("SUCCESS - Cache has beeen saved")
    return True
